@@ -1,7 +1,9 @@
+import traceback
 from enum import Enum
 from typing import Optional, List
 
 # noinspection PyProtectedMember
+import sys
 from pyspark.sql.types import (
     StructType,
     StructField,
@@ -17,6 +19,10 @@ from pyspark.sql.types import (
     NumericType,
 )
 
+from spark_data_frame_comparer.sparjk_data_frame_comparer_generic_exception import (
+    SparkDataFrameComparerGenericException,
+)
+
 
 class SchemaCompareErrorType(Enum):
     INFO = 1
@@ -87,11 +93,38 @@ class SchemaComparer:
 
         errors: List[SchemaCompareError] = []
         desired_field: StructField
+        i: int = 0
         for desired_field in desired_schema.fields:
-            # first see if the field exists in source_schema
-            if desired_field.name not in source_schema.names:
+            # first see if the field exists in source_schema.
+            # if destination field is nullable then it is fine if there is no source field
+            if i >= len(source_schema.names):
+                # nothing to match so skip
+                if not desired_field.nullable:
+                    errors.append(
+                        SchemaCompareError(
+                            column=f"{parent_column_name}.{desired_field.name}",
+                            error_type=SchemaCompareErrorType.ERROR,
+                            error=f"{parent_column_name}.{desired_field.name} not found in source and is not nullable",
+                            source_schema=NullType(),
+                            desired_schema=desired_field.dataType,
+                        )
+                    )
+            elif desired_field.name != source_schema.names[i]:
+                if desired_field.name in source_schema.names:
+                    # it's in wrong place
+                    errors.append(
+                        SchemaCompareError(
+                            column=f"{parent_column_name}.{desired_field.name}",
+                            error_type=SchemaCompareErrorType.ERROR,
+                            error=f"{parent_column_name}.{desired_field.name} is not in the same order as source."
+                            f" source=[{','.join(source_schema.names)}]"
+                            f" destination=[{','.join(desired_schema.names)}]",
+                            source_schema=NullType(),
+                            desired_schema=desired_field.dataType,
+                        )
+                    )
                 # if field is nullable then it's ok
-                if desired_field.nullable:
+                elif desired_field.nullable:
                     errors.append(
                         SchemaCompareError(
                             column=f"{parent_column_name}.{desired_field.name}",
@@ -111,13 +144,14 @@ class SchemaComparer:
                             desired_schema=desired_field.dataType,
                         )
                     )
-                continue
-            source_field: StructField = source_schema[desired_field.name]
-            errors += SchemaComparer.compare_data_type(
-                parent_column_name=f"{parent_column_name}.{desired_field.name}",
-                source_schema=source_field.dataType,
-                desired_schema=desired_field.dataType,
-            )
+            else:
+                i += 1  # match found so increment source
+                source_field: StructField = source_schema[desired_field.name]
+                errors += SchemaComparer.compare_data_type(
+                    parent_column_name=f"{parent_column_name}.{desired_field.name}",
+                    source_schema=source_field.dataType,
+                    desired_schema=desired_field.dataType,
+                )
         return errors
 
     @staticmethod
@@ -276,10 +310,15 @@ class SchemaComparer:
         source_schema: DataType,
         desired_schema: DataType,
     ) -> SchemaComparerResult:
-        result: SchemaComparerResult = SchemaComparerResult()
-        result.errors = SchemaComparer.compare_data_type(
-            parent_column_name=parent_column_name,
-            source_schema=source_schema,
-            desired_schema=desired_schema,
-        )
-        return result
+        try:
+            result: SchemaComparerResult = SchemaComparerResult()
+            result.errors = SchemaComparer.compare_data_type(
+                parent_column_name=parent_column_name,
+                source_schema=source_schema,
+                desired_schema=desired_schema,
+            )
+            return result
+        except:
+            e = sys.exc_info()[0]
+            msg = traceback.format_exc()
+            raise SparkDataFrameComparerGenericException(e, msg) from e
